LeanCallbackFlow

Enum LeanCallbackFlow 

pub enum LeanCallbackFlow {
    Continue,
    Stop,
}
Flow decision returned by a Rust callback.

Lean shims should continue their callback loop only when the trampoline returns LeanCallbackStatus::Ok. Returning Stop asks the Lean loop to stop cleanly and return [LeanCallbackStatus::Stopped).

Variants



Continue

Continue the Lean-side callback loop.



Stop

Stop the Lean-side callback loop without treating the callback as a panic or stale-handle failure.