LeanModuleInitializer

Struct LeanModuleInitializer 

pub struct LeanModuleInitializer { /* private fields */ }
Initializer for a Lean module hosted by a loaded dylib.

Implementations

Source

impl LeanModuleInitializer

pub fn new(package: impl Into<String>, module: impl Into<String>) -> Self

Create an initializer descriptor from Lake package and root module names.

pub fn package_name(&self) -> &str

Lake package name used by the initializer.

pub fn module_name(&self) -> &str

Root Lean module name used by the initializer.