#[repr(u8)]pub enum LeanCallbackStatus {
Ok = 0,
StaleHandle = 1,
Panic = 2,
WrongPayload = 3,
Stopped = 4,
}Expand description
Status returned by the Rust callback trampoline to Lean.
Lean shims should treat any value other than Ok as a request
to stop the current callback loop and return the status to Rust.
Variants
Ok = 0
The callback ran successfully.
StaleHandle = 1
Lean called an id that is no longer registered.
Panic = 2
The registered Rust callback panicked and the trampoline contained it.
WrongPayload = 3
Lean called a handle through a trampoline for the wrong payload type.
Stopped = 4
The registered Rust callback asked Lean to stop cleanly.
Implementations