pub struct LeanModuleInitializer { /* private fields */ }Expand description
Initializer for a Lean module hosted by a loaded dylib.
Implementations
Sourceimpl LeanModuleInitializer
impl LeanModuleInitializer
Sourcepub fn new(package: impl Into<String>, module: impl Into<String>) -> Self
pub fn new(package: impl Into<String>, module: impl Into<String>) -> Self
Create an initializer descriptor from Lake package and root module names.
Sourcepub fn package_name(&self) -> &str
pub fn package_name(&self) -> &str
Lake package name used by the initializer.
Sourcepub fn module_name(&self) -> &str
pub fn module_name(&self) -> &str
Root Lean module name used by the initializer.